#include "sensor.h"
#include "serial.h"
#include "stepper.h"
#include "logic_lib.h"

const int CALIBRATION_BUTTON_PIN = 13;
const int START_BUTTON_PIN = 12;
const bool SKIP_CALIBRATION = false; 
const bool DOWN_ROTATION_Z = false; 

int currentRotation;
int BOTTOM_ROTATION;
int TOP_ROTATION;

void setup() {
  InitializeSerial();
  InitializeSensorCommunicationI2C();
  InitializeSteppers();
  InitializeLogic(START_BUTTON_PIN);


  if (SKIP_CALIBRATION) return;

  Serial.println("Press START to initialize calibration");
  while (!digitalRead(START_BUTTON_PIN));
  Serial.println("Calibrating -- press CALIBRATION when the Z-axis is in the right position");
  Calibrate(CALIBRATION_BUTTON_PIN, DOWN_ROTATION_Z, BOTTOM_ROTATION, TOP_ROTATION, currentRotation);
  Serial.print("Current rot is ");
  Serial.println(currentRotation);
  Serial.print("Bottom rot is ");
  Serial.println(BOTTOM_ROTATION);
  Serial.print("Top rot is ");
  Serial.println(TOP_ROTATION);
  Serial.println("Calibration complete -- press START to begin");
}

void loop() {
  WaitForStartup(START_BUTTON_PIN, currentRotation, BOTTOM_ROTATION, TOP_ROTATION, DOWN_ROTATION_Z);
}



void Calibrate(int calibrationButtonPin, bool downRotation, int &_bottomRot, int &_topRot, int &_currentRot) {
  pinMode(calibrationButtonPin, INPUT); // CHECK AND SEE IF PULLUP OR PULLDOWN

  int bottomRot = 0;
  int topRot;
  int currentRot = 0;

  while (digitalRead(calibrationButtonPin) == LOW) { // assumes x and y are the two z motors and z is the wheel motor
    TurnXYOpposite(180, !downRotation);
    //TurnY(180, !downRotation);
    currentRot += 180; // going up = positive angle
    Serial.println(currentRot);
    //delay(1/*500*/);
  }

  bottomRot = currentRot;

  _bottomRot = bottomRot;
  _topRot = topRot;
  _currentRot = currentRot;
}