#include "logic_lib.h"
#include "stepper.h"
#include "sensor.h"

const DIRECTION CLEANING_DIRECTION = FORWARD;

void InitializeLogic(int startButtonPin) {
  pinMode(startButtonPin, INPUT); // TODO FIGURE THIS OUT INPUT TYPE FOR THE BUTTON
  pinMode(OUTSIDE_SENSOR_INDICATOR_PIN, INPUT);
}

void WaitForStartup(int startButtonPin, int& currentRot, int bottomRot, int topRot, bool downRotation) {
  while (1) {
    if (StartCondition(startButtonPin)) {
      Serial.println("Starting");
      MainFlow(currentRot, bottomRot, topRot, downRotation);
    }
  }
}

bool StartCondition(int startButtonPin) {
  return (digitalRead(startButtonPin) == HIGH);
}

void SetRagPosition(RAG_POSITION ragPosition, int& currentRot, int bottomRot, int topRot, bool downRotation) {
  int target;
  if (ragPosition == DOWN) {
    target = topRot; // check if flipped
  }
  else {
    target = bottomRot; // check if flipped
  }

  MoveToRot(currentRot, target, downRotation);
}

void MoveToRot(int& currentRot, int targetRot, bool downRotation) {
  Serial.print("Moving ");
  int difference = targetRot - currentRot; // positive difference = move down
  Serial.println(difference);
  for (int i = 0; i < targetRot * (targetRot < 0 ? -1 : 1); i += 180) {
    TurnXYOpposite(180, (difference > 0) ? !downRotation : downRotation);
  }
  
}

bool HitEdge(DIRECTION direction) {
  if (direction == FORWARD) return (digitalRead(OUTSIDE_SENSOR_INDICATOR_PIN) == HIGH);

  float mm, _;
  
  SensorVal(mm, _, _, direction);
  return (mm >= offTableThreshold);
}

DIRECTION MoveUntilEdge(DIRECTION currentDir) {
  
    while (!HitEdge(currentDir)) {
      TurnZ(180, currentDir);
      delay(0.5);
    }
    
    return ((currentDir == FORWARD) ? BACK : FORWARD);
}

void MainFlow(int &currentRot, int bottomRot, int topRot, bool downRotation) {
  DIRECTION currentDirection = CLEANING_DIRECTION;
  SetRagPosition(DOWN, currentRot, bottomRot, topRot, downRotation);
  Serial.println("moving until edge...");
  currentDirection = MoveUntilEdge(currentDirection);
  SetRagPosition(UP, currentRot, bottomRot, topRot, downRotation);
  MoveUntilEdge(currentDirection);
}