#include "logic_lib.h"
#include "stepper.h"
#include "sensor.h"

const DIRECTION CLEANING_DIRECTION = FORWARD;

void InitializeLogic(int startButtonPin) {
  pinMode(startButtonPin, INPUT); // TODO FIGURE THIS OUT INPUT TYPE FOR THE BUTTON
}

void WaitForStartup(int startButtonPin, int& currentRot, int bottomRot, int topRot, bool downRotation) {
  while (1) {
    if (StartCondition(startButtonPin)) {
      MainFlow(currentRot, bottomRot, topRot, downRotation);
    }
  }
}

bool StartCondition(int startButtonPin) {
  return (digitalRead(startButtonPin) == HIGH);
}

void SetRagPosition(RAG_POSITION ragPosition, int& currentRot, int bottomRot, int topRot, bool downRotation) {
  int target;
  if (ragPosition == DOWN) {
    target = bottomRot;
  }
  else {
    target = topRot;
  }

  MoveToRot(currentRot, target, downRotation);
}

void MoveToRot(int& currentRot, int targetRot, bool downRotation) {
  int difference = targetRot - currentRot; // positive difference = move down
  TurnXYOpposite(difference * (difference < 0 ? -1 : 1), (difference < 0) ? !downRotation : downRotation);
}

bool HitEdge(DIRECTION direction, int offTableThreshold) {
  float mm, _;
  SensorVal(mm, _, _, direction);
  return (mm >= offTableThreshold);
}

DIRECTION MoveUntilEdge(DIRECTION currentDir) {
  

    while (!HitEdge(currentDir)) {
      TurnZ(180, currentDir);
      delay(250);
    }
    
    return ((currentDir == FORWARD) ? BACK : FORWARD);
}

void MainFlow(int &currentRot, int bottomRot, int topRot, bool downRotation) {
  DIRECTION currentDirection = CLEANING_DIRECTION;
  SetRagPosition(DOWN, currentRot, bottomRot, topRot, downRotation);
  currentDirection = MoveUntilEdge(currentDirection);
  SetRagPosition(UP, currentRot, bottomRot, topRot, downRotation);
  MoveUntilEdge(currentDirection);
}